diff -r -u febootstrap-3.20/src/febootstrap_cmdline.ml febootstrap-3.20_ebal/src/febootstrap_cmdline.ml
--- febootstrap-3.20/src/febootstrap_cmdline.ml	2012-08-31 18:28:58.000000000 +0300
+++ febootstrap-3.20_ebal/src/febootstrap_cmdline.ml	2012-12-19 13:54:50.223488364 +0200
@@ -27,6 +27,7 @@
 let verbose = ref false
 let warnings = ref true
 let yum_config = ref None
+let pacman_config = ref None
 
 let print_version () =
   printf "%s %s\n" Config.package_name Config.package_version;
@@ -38,6 +39,10 @@
 let set_yum_config str =
   yum_config := Some str
 
+let set_pacman_config str =
+  pacman_config := Some str
+
+
 let argspec = Arg.align [
   "--exclude", Arg.String add_exclude,
     "regexp Exclude packages matching regexp";
@@ -63,6 +68,8 @@
     " Print package name and version, and exit";
   "--yum-config", Arg.String set_yum_config,
     "file Set alternate yum configuration file";
+  "--pacman-config", Arg.String set_pacman_config,
+    "file Set alternate pacman configuration file";
 ]
 let anon_fn str =
   packages := str :: !packages
@@ -96,5 +103,6 @@
 let verbose = !verbose
 let warnings = !warnings
 let yum_config = !yum_config
+let pacman_config = !pacman_config
 
 let debug fs = ksprintf (fun str -> if verbose then print_endline str) fs
diff -r -u febootstrap-3.20/src/febootstrap_cmdline.mli febootstrap-3.20_ebal/src/febootstrap_cmdline.mli
--- febootstrap-3.20/src/febootstrap_cmdline.mli	2012-08-31 18:28:58.000000000 +0300
+++ febootstrap-3.20_ebal/src/febootstrap_cmdline.mli	2012-12-19 13:38:05.213215075 +0200
@@ -50,3 +50,6 @@
 
 val yum_config : string option
   (** Yum configuration file. *)
+
+val pacman_config : string option
+  (**pacman configuration file. *)
diff -r -u febootstrap-3.20/src/febootstrap_pacman.ml febootstrap-3.20_ebal/src/febootstrap_pacman.ml
--- febootstrap-3.20/src/febootstrap_pacman.ml	2012-08-31 18:28:58.000000000 +0300
+++ febootstrap-3.20_ebal/src/febootstrap_pacman.ml	2012-12-19 13:54:11.150143592 +0200
@@ -52,11 +52,13 @@
   (* Download the packages. I could use wget `pacman -Sp`, but this
    * narrows the pacman -Sy window
    *)
+
   List.iter (
     fun pkg ->
       let cmd =
-        sprintf "umask 0000; cd %s && mkdir -p var/lib/pacman && fakeroot pacman -Syw --noconfirm --cachedir=$(pwd) --root=$(pwd) %s"
+        sprintf "umask 0000; cd %s && mkdir -p var/lib/pacman && fakeroot pacman --config %s -Syw --noconfirm --cachedir=$(pwd) --root=$(pwd) %s"
         (Filename.quote tmpdir)
+	(match pacman_config with None -> "/etc/pacman.conf" | Some filename -> filename)
         pkg in
       if Sys.command cmd <> 0 then (
           (* The package is not in the main repos, check the aur *)
